==> phpAdsNew_1.6.2.tar.gz: phpAdsNew_1.6.2/dutch.inc.php <==
<?

$strHome = "Hoofdpagina";
$date_format = "%m/%d/%Y";
$time_format = "%H:%i:%S";
$strMySQLError = "MySQL-Fout:";
$strAdminstration = "Adminstratie";
$strAddClient = "Add klant toe";
$strModifyClient = "Wijzig klant";
$strDeleteClient = "Verwijder klant";
$strViewClientStats = "Bekijk statistieken klant";
$strClientName = "Klant";
$strContact = "Contact";
$strEMail = "E-Mail";
$strViews = "AdViews";
$strClicks = "AdClicks";
$strTotalViews = "Totaal AdViews";
$strTotalClicks = "Totaal AdClicks";
$strCTR = "Click-Throuh Ratio";
$strTotalClients = "Totaal aantal klanten";
$strActiveClients = "Actieve klanten";
$strActiveBanners = "Actieve banners";
$strLogout = "Uitloggen";
$strCreditStats = "Kredietstatistieken";
$strViewCredits = "Adview krediet";
$strClickCredits = "Adclick krediet";
$strPrevious = "Vorige";
$strNext = "Volgende";
$strNone = "Geen";
$strViewsPurchased = "Gekochte Advertentieviews";
$strClicksPurchased = "Gekochte Advertentieclicks";
$strDaysPurchased = "Gekochte Advertentiedagen";
$strHTML = "HTML";
$strAddSep = "Vul OFWEL een van beide bovenstaande velden OF onderstaand veld in!";
$strTextBelow = "Tekst onder banner";
$strSubmit = "Stuur banner op";
$strUsername = "Gebruikersnaam";
$strPassword = "Paswoord";
$strBannerAdmin = "Banneradminstratie voor";
$strBannerAdminAcl = "Banner ACL adminstratie voor";
$strNoBanners = "Geen banners gevonden";
$strBanner = "Banner";
$strCurrentBanner = "Huidige banner";
$strDelete = "Verwijder";
$strAddBanner  = "Voeg banner toe";
$strModifyBanner  = "Wijzig banner";
$strModifyBannerAcl  = "Wijzig banner ACL";
$strURL = "Gelinked aan URL (incl. http://)";
$strKeyword = "Sleutelwoord";
$strWeight = "Gewicht";
$strAlt = "Alt-Text";
$strAccessDenied = "Toegang geweigerd";
$strNotAdmin = "U heeft geen administratie-privileges";
$strClientAdded = "De klant werd toegevoegd.";
$strClientModified = "De klant werd gewijzigd.";
$strClientDeleted = "De klant werd verwijderd.";
$strBannerAdmin = "Banneradminstratie";
$strBannerAdded = "De banner werd toegevoegd.";
$strBannerModified = "De banner werd gewijzigd.";
$strBannerDeleted = "De banner werd verwijderd";
$strBannerChanged = "De banner werd gewijzigd";
$strStats = "Statistieken";
$strDailyStats = "Dagelijkse statistieken";
$strDetailStats = "Gedetailleerde statistieken";
$strCreditStats = "Kredietstatistieken";
$strActive = "actief";
$strActivate = "Activeer";
$strDeActivate = "Deactiveer";
$strAuthentification = "Authenticatie";
$strGo = "Start";
$strLinkedTo = "gelinked aan";
$strBannerID = "Banner-ID";
$strClientID = "Klant-ID";
$strMailSubject = "Advertentierapport";
$strMailSubjectDeleted = "Gedeactiveerde banners";
$strMailHeader = 'Beste ".$clients[$i]["contact"].",\n';
$strMailBannerStats = 'Bijgevoegd vind u de banner-statistieken van ".$clients[$i]["clientname"].":';
$strMailFooter = 'Beste,\n   $phpAds_admin_fullname';
$strMailNothingLeft = "U heeft geen AdViews meer over in uw account bij ons. Daarom zijn uw banners gedeactiveerd.\n\nAls u nieuwe AdViews wilt inkopen, neem dan gerust contact met ons op. We horen graag van u.";
$strLogMailSent = "[phpAdsNew] Statistieken successvol verzonden.";
$strLogErrorClients = "[phpAdsNew] An error occurred while trying to fetch the clients from the database.";
$strLogErrorBanners = "[phpAdsNew] An error occurred while trying to fetch the banners from the database.";
$strLogErrorViews = "[phpAdsNew] An error occurred while trying to fetch the adviews from the database.";
$strLogErrorClicks = "[phpAdsNew] An error occurred while trying to fetch the adclicks from the database.";
$strLogErrorDisactivate = "[phpAdsNew] An error occurred while trying to disactivate a banner.";
$strRatio = "Click-Through Ratio";
$strChooseBanner = "Gelieve het type banner te kiezen.";
$strMySQLBanner = "Banner opgeslagen in MySQL";
$strURLBanner = "Banner waarnaar verwezen wordt d.m.v. een URL";
$strHTMLBanner = "HTML-banner";
$strNewBannerFile = "Nieuw banner-bestand";
$strNewBannerURL = "Nieuwe banner-URL (incl. http://)";
$strWidth = "Breedte";
$strHeight = "Hoogte";
$strTotalViews7Days = "Totaal AdViews voorbije 7 dagen";
$strTotalClicks7Days = "Totaal AdClicks voorbije 7 dagen";
$strAvgViews7Days = "Gemiddelde AdViews voorbije 7 dagen";
$strAvgClicks7Days = "Gemiddelde AdClicks voorbije 7 dagen";
$strTopTenHosts = "Top tien hosts";
$strConfirmDeleteClient = "Bent u zeker dat u deze klant wil verwijdern ?";
$strClientIP = "IP adres bezoeker";
$strUserAgent = "User agent regexp";
$strWeekDay = "Weekdag (0 - 6)";
$strDomain = "Domein (zonder punt)";
$strSource = "Bronpagina";
$strTime = "Tijd";
$strAllow = "Toestaan";
$strDeny = "Weigeren";
$strResetStats = "Wis Statistieken";
?>

==> phpAdsNew_1.8.0.tar.gz: phpAdsNew_1.8.0/dutch.inc.php <==
<?

$strHome = "Hoofdpagina";
$date_format = "%m/%d/%Y";
$time_format = "%H:%i:%S";
$strMySQLError = "MySQL-Fout:";
$strAdminstration = "Adminstratie";
$strAddClient = "Add klant toe";
$strModifyClient = "Wijzig klant";
$strDeleteClient = "Verwijder klant";
$strViewClientStats = "Bekijk statistieken klant";
$strClientName = "Klant";
$strContact = "Contact";
$strEMail = "E-Mail";
$strViews = "AdViews";
$strClicks = "AdClicks";
$strTotalViews = "Totaal AdViews";
$strTotalClicks = "Totaal AdClicks";
$strCTR = "Click-Through Ratio";
$strTotalClients = "Totaal aantal klanten";
$strActiveClients = "Actieve klanten";
$strActiveBanners = "Actieve banners";
$strLogout = "Uitloggen";
$strCreditStats = "Kredietstatistieken";
$strViewCredits = "Adview krediet";
$strClickCredits = "Adclick krediet";
$strPrevious = "Vorige";
$strNext = "Volgende";
$strNone = "Geen";
$strViewsPurchased = "Gekochte Advertentieviews";
$strClicksPurchased = "Gekochte Advertentieclicks";
$strDaysPurchased = "Gekochte Advertentiedagen";
$strHTML = "HTML";
$strAddSep = "Vul OFWEL een van beide bovenstaande velden OF onderstaand veld in!";
$strTextBelow = "Tekst onder banner";
$strSubmit = "Stuur banner op";
$strUsername = "Gebruikersnaam";
$strPassword = "Paswoord";
$strBannerAdmin = "Banneradminstratie voor";
$strBannerAdminAcl = "Banner ACL adminstratie voor";
$strNoBanners = "Geen banners gevonden";
$strBanner = "Banner";
$strCurrentBanner = "Huidige banner";
$strDelete = "Verwijder";
$strAddBanner  = "Voeg banner toe";
$strModifyBanner  = "Wijzig banner";
$strModifyBannerAcl  = "Wijzig banner ACL";
$strURL = "Gelinked aan URL (incl. http://)";
$strKeyword = "Sleutelwoord";
$strWeight = "Gewicht";
$strAlt = "Alt-Text";
$strAccessDenied = "Toegang geweigerd";
$strNotAdmin = "U heeft geen administratie-privileges";
$strClientAdded = "De klant werd toegevoegd.";
$strClientModified = "De klant werd gewijzigd.";
$strClientDeleted = "De klant werd verwijderd.";
$strBannerAdmin = "Banneradminstratie";
$strBannerAdded = "De banner werd toegevoegd.";
$strBannerModified = "De banner werd gewijzigd.";
$strBannerDeleted = "De banner werd verwijderd";
$strBannerChanged = "De banner werd gewijzigd";
$strStats = "Statistieken";
$strDailyStats = "Dagelijkse statistieken";
$strDetailStats = "Gedetailleerde statistieken";
$strCreditStats = "Kredietstatistieken";
$strActive = "actief";
$strActivate = "Activeer";
$strDeActivate = "Deactiveer";
$strAuthentification = "Authenticatie";
$strGo = "Start";
$strLinkedTo = "gelinked aan";
$strBannerID = "Banner-ID";
$strClientID = "Klant-ID";
$strMailSubject = "Advertentierapport";
$strMailSubjectDeleted = "Gedeactiveerde banners";
$strMailHeader = 'Beste ".$clients[$i]["contact"].",\n';
$strMailBannerStats = 'Bijgevoegd vind u de banner-statistieken van ".$clients[$i]["clientname"].":';
$strMailFooter = 'Beste,\n   $phpAds_admin_fullname';
$strMailNothingLeft = "U heeft geen AdViews meer over in uw account bij ons. Daarom zijn uw banners gedeactiveerd.\n\nAls u nieuwe AdViews wilt inkopen, neem dan gerust contact met ons op. We horen graag van u.";
$strLogMailSent = "[phpAdsNew] Statistieken successvol verzonden.";
$strLogErrorClients = "[phpAdsNew] An error occurred while trying to fetch the clients from the database.";
$strLogErrorBanners = "[phpAdsNew] An error occurred while trying to fetch the banners from the database.";
$strLogErrorViews = "[phpAdsNew] An error occurred while trying to fetch the adviews from the database.";
$strLogErrorClicks = "[phpAdsNew] An error occurred while trying to fetch the adclicks from the database.";
$strLogErrorDisactivate = "[phpAdsNew] An error occurred while trying to disactivate a banner.";
$strRatio = "Click-Through Ratio";
$strChooseBanner = "Gelieve het type banner te kiezen.";
$strMySQLBanner = "Banner opgeslagen in MySQL";
$strURLBanner = "Banner waarnaar verwezen wordt d.m.v. een URL";
$strHTMLBanner = "HTML-banner";
$strNewBannerFile = "Nieuw banner-bestand";
$strNewBannerURL = "Nieuwe banner-URL (incl. http://)";
$strWidth = "Breedte";
$strHeight = "Hoogte";
$strTotalViews7Days = "Totaal AdViews voorbije 7 dagen";
$strTotalClicks7Days = "Totaal AdClicks voorbije 7 dagen";
$strAvgViews7Days = "Gemiddelde AdViews voorbije 7 dagen";
$strAvgClicks7Days = "Gemiddelde AdClicks voorbije 7 dagen";
$strTopTenHosts = "Top tien hosts";
$strConfirmDeleteClient = "Bent u zeker dat u deze klant wil verwijdern ?";
$strClientIP = "IP adres bezoeker";
$strUserAgent = "User agent regexp";
$strWeekDay = "Weekdag (0 - 6)";
$strDomain = "Domein (zonder punt)";
$strSource = "Bronpagina";
$strTime = "Tijd";
$strAllow = "Toestaan";
$strDeny = "Weigeren";
$strResetStats = "Wis Statistieken";
$strConfirmResetStats = "Wil u echt de statistieken wissen voor deze klant ?";
$strExpiration = "Vervalling";
$strDaysLeft = "Dagen te gaan";
$strEstimated = "Geschatte vervaldag";
$strConfirm = "Bent u zeker ?";
$strBannerNoStats = "Geen statistieken voor deze banner!";
$strWeek = "Week";
$strWeeklyStats = "Weekelijkse statistieken";
$strWeekDay = "Weekdag";
$strDate = "Datum";
$strCTRShort = "CTR";
$strDayShortCuts=array("Zo","Ma","Di","Wo","Do","Vr","Za");
$strShowWeeks="Max. aantal getoonde weken";
$strAll="alle";
$strAvg="Gem.";
$strHourly="Views/Clicks per uur";
$strTotal = "Totaal";
$strUnlimited = "Onbegrensd";

?>
